@@ -19,24 +19,16 @@ class SetUserMixin:
         self.user = None
 
     def get(self, request, *args, **kwargs):
-        self.user = request.resource_owner
-        print(f'USER: {self.user}')
-        return super(SetUserMixin, self).get(request=request, *args, **kwargs)
+        return super(SetUserMixin, self).get(request=request,user=request.resource_owner, *args, **kwargs)
 
     def post(self, request, *args, **kwargs):
-        self.user = request.resource_owner
-        print(f'USER: {self.user}')
-        return super(SetUserMixin, self).get(request=request, *args, **kwargs)
+        return super(SetUserMixin, self).post(request=request, *args, **kwargs)
 
     def put(self, request, *args, **kwargs):
-        self.user = request.resource_owner
-        print(f'USER: {self.user}')
-        return super(SetUserMixin, self).get(request=request, *args, **kwargs)
+        return super(SetUserMixin, self).put(request=request, *args, **kwargs)
 
     def delete(self, request, *args, **kwargs):
-        self.user = request.resource_owner
-        print(f'USER: {self.user}')
-        return super(SetUserMixin, self).get(request=request, *args, **kwargs)
+        return super(SetUserMixin, self).delete(request=request, *args, **kwargs)
 
 
 @method_decorator([csrf_exempt, view_catch_error], name='dispatch')
